// MAX7456 VIDEO_MODE_0 register
#define VIDEO_MODE_0_WRITE        0x00          
#define VIDEO_MODE_0_READ         0x80
#define VIDEO_MODE_0_40_PAL               0x40
#define VIDEO_MODE_0_20_NoAutoSync        0x20
#define VIDEO_MODE_0_10_SyncInt           0x10
#define VIDEO_MODE_0_08_EnOSD             0x08
#define VIDEO_MODE_0_04_UpdateVsync       0x04
#define VIDEO_MODE_0_02_Reset             0x02
#define VIDEO_MODE_0_01_EnVideo           0x01
// VIDEO MODE 0 bitmap
#define NTSC                      0x00
#define PAL                       0x40
#define AUTO_SYNC                 0x00
#define EXT_SYNC                  0x20
#define INT_SYNC                  0x30
#define OSD_EN                    0x08
#define VERT_SYNC_IMM             0x00
#define VERT_SYNC_VSYNC           0x04
#define SW_RESET                  0x02
#define BUF_EN                    0x00
#define BUF_DI                    0x01
//
// MAX7456 VIDEO_MODE_1 register
#define VIDEO_MODE_1_WRITE        0x01
#define VIDEO_MODE_1_READ         0x81
//
// MAX7456 DM_MODE register
#define DM_MODE_WRITE             0x04
#define DM_MODE_READ              0x84
//
// MAX7456 DM_ADDRH register
#define DM_ADDRH_WRITE            0x05
#define DM_ADDRH_READ             0x85
//
// MAX7456 DM_ADDRL register
#define DM_ADDRL_WRITE            0x06
#define DM_ADDRL_READ             0x87
//
// MAX7456 DM_CODE_IN register
#define DM_CODE_IN_WRITE          0x07
#define DM_CODE_IN_READ           0x87
//
// MAX7456 DM_CODE_OUT register
#define DM_CODE_OUT_READ          0xB0
//
// MAX7456 FM_MODE register
#define FM_MODE_WRITE             0x08
#define FM_MODE_READ              0x88
//
// MAX7456 FM_ADDRH register
#define FM_ADDRH_WRITE            0x09
#define FM_ADDRH_READ             0x89
//
// MAX7456 FM_ADDRL register
#define FM_ADDRL_WRITE            0x0A
#define FM_ADDRL_READ             0x8A
//
// MAX7456 FM_DATA_IN register
#define FM_DATA_IN_WRITE          0x0B
#define FM_DATA_IN_READ           0x8B
//
// MAX7456 FM_DATA_OUT register
#define FM_DATA_OUT_READ          0xC0
//
// MAX7456 STATUS register
#define STATUS_READ               0xA0
#define STATUS_40_RESET_BUSY           0x40
#define STATUS_20_NVRAM_BUSY           0x20
#define STATUS_04_LOSS_OF_SYNC         0x04
#define STATUS_02_PAL_DETECTED         0x02
#define STATUS_01_NTSC_DETECTED        0x01
#define MAX_screen_size 420
#define MAX_screen_rows 16
#define WHITE_level_80 0x03
#define WHITE_level_90 0x02
#define WHITE_level_100 0x01
#define WHITE_level_120 0x00
//MAX7456 opcodes
#define DMM_reg   0x04
#define DMAH_reg  0x05
#define DMAL_reg  0x06
#define DMDI_reg  0x07
#define VM0_reg   0x00
#define VM1_reg   0x01
// video mode register 0 bits
#define VIDEO_BUFFER_DISABLE 0x01
#define MAX7456_RESET 0x02
#define VERTICAL_SYNC_NEXT_VSYNC 0x04
#define OSD_ENABLE 0x08
#define SYNC_MODE_AUTO 0x00
#define SYNC_MODE_INTERNAL 0x30
#define SYNC_MODE_EXTERNAL 0x20
#define VIDEO_MODE_PAL 0x40
#define VIDEO_MODE_NTSC 0x00

// video mode register 1 bits
// duty cycle is on_off
#define BLINK_DUTY_CYCLE_50_50 0x00
#define BLINK_DUTY_CYCLE_33_66 0x01
#define BLINK_DUTY_CYCLE_25_75 0x02
#define BLINK_DUTY_CYCLE_75_25 0x03

// blinking time
#define BLINK_TIME_0 0x00
#define BLINK_TIME_1 0x04
#define BLINK_TIME_2 0x08
#define BLINK_TIME_3 0x0C

// background mode brightness (percent)
#define BACKGROUND_BRIGHTNESS_0 0x00
#define BACKGROUND_BRIGHTNESS_7 0x01
#define BACKGROUND_BRIGHTNESS_14 0x02
#define BACKGROUND_BRIGHTNESS_21 0x03
#define BACKGROUND_BRIGHTNESS_28 0x04
#define BACKGROUND_BRIGHTNESS_35 0x05
#define BACKGROUND_BRIGHTNESS_42 0x06
#define BACKGROUND_BRIGHTNESS_49 0x07

#define BACKGROUND_MODE_GRAY 0x40

//MAX7456 commands
#define CLEAR_display 0x04
#define CLEAR_display_vert 0x06
#define END_string 0xff
// with NTSC
#define ENABLE_display 0x08
#define ENABLE_display_vert 0x0c
#define MAX7456_reset 0x02
#define DISABLE_display 0x00


extern unsigned short int read_status_osd();
extern void set_vm0(void);
extern void set_vm1(void);
void spiWriteReg(const unsigned char regAddr, const unsigned char regData);
void clear_osd(void);
void osd_offset_hor(const unsigned char offset);
void osd_offset_vert(const unsigned char offset);
void osd_mem_high(void);
void osd_mem_low(void);
void osd_draw_char(unsigned char position,unsigned char zeichen);
void osd_rest_chip(void);
void OSD_write_to_screen(const char s[], unsigned char x, unsigned char y);
